@@ -17,9 +17,11 @@ setMethod("initialize", "VariableCatalog", function(.Object, ...) {
 })
 
 .discardedTuple <- function(x) isTRUE(x[["discarded"]])
+.secureTuple <- function(x) isTRUE(x[["secure"]])
 
 setMethod("active", "VariableCatalog", function(x) {
     index(x) <- Filter(Negate(.discardedTuple), index(x))
+    index(x) <- Filter(Negate(.secureTuple), index(x))
     return(x)
 })
 
