@@ -24,14 +24,16 @@ with_mock_crunch({
             projects()
         )
         expect_identical(
-            projects() %>% cd("Project One/Project Two") %>% cd("/Project One"),
+            projects() %>% cd("Project One/Project Two") %>% cd("/Project One"), # nolint
             cd(projects(), "Project One")
         )
     })
 
     test_that("cd personal", {
-        expect_identical(self(cd(projects(), "~")),
-            "https://app.crunch.io/api/projects/personal/")
+        expect_identical(
+            self(cd(projects(), "~")),
+            "https://app.crunch.io/api/projects/personal/"
+        )
         expect_identical(
             projects() %>%
                 cd("Project One/Project Two") %>%
@@ -44,17 +46,23 @@ with_mock_crunch({
     test_that("folder() and rootFolder() for projects", {
         expect_null(folder(projects()))
         expect_identical(folder(cd(projects(), "Project One")), projects())
-        expect_identical(folder(cd(projects(), "Project One/Project Two")),
-            cd(projects(), "Project One"))
-        expect_identical(rootFolder(cd(projects(), "Project One/Project Two")),
-            projects())
+        expect_identical(
+            folder(cd(projects(), "Project One/Project Two")),
+            cd(projects(), "Project One")
+        )
+        expect_identical(
+            rootFolder(cd(projects(), "Project One/Project Two")),
+            projects()
+        )
     })
 
     test_that("path()", {
         expect_identical(path(projects()), "/")
-        expect_identical(path(cd(projects(), "Project One")), "/Project One")
-        expect_identical(path(cd(projects(), "Project One/Project Two")),
-            "/Project One/Project Two")
+        expect_identical(path(cd(projects(), "Project One")), "/Project One") # nolint
+        expect_identical(
+            path(cd(projects(), "Project One/Project Two")),
+            "/Project One/Project Two" # nolint
+        )
     })
 
     create_group_2 <- '{"element":"shoji:entity","body":{"name":"Group 2"}}'
@@ -170,7 +178,6 @@ with_mock_crunch({
             "https://app.crunch.io/api/projects/project5/",
             '{"element":"shoji:catalog",',
             '"index":{"https://app.crunch.io/api/projects/project2/":{}}}'
-
         )
     })
 
@@ -217,7 +224,10 @@ with_mock_crunch({
             expect_error(
                 proj %>%
                     rmdir("Project Two"),
-                "Cannot remove 'Project Two' because it is not empty. Move its contents somewhere else and then retry."
+                paste0(
+                    "Cannot remove 'Project Two' because it is not empty. Move ",
+                    "its contents somewhere else and then retry."
+                )
             )
         })
     })
@@ -238,8 +248,10 @@ with_mock_crunch({
 
     test_that("members() methods work on ProjectFolders", {
         expect_is(members(proj), "MemberCatalog")
-        expect_PATCH(members(proj) <- "me@myself.io",
-            self(members(proj)))
+        expect_PATCH(
+            members(proj) <- "me@myself.io",
+            self(members(proj))
+        )
     })
 
     test_that("print project folders", {
