@@ -9,12 +9,16 @@ with_mock_crunch({
     })
 
     test_that("Changing numeric type by <- makes requests", {
-        expect_POST(type(ds$birthyr) <- "categorical",
-            'https://app.crunch.io/api/datasets/1/variables/birthyr/cast/',
-            '{"cast_as":"categorical"}')
-        expect_POST(type(ds$birthyr) <- "text",
-            'https://app.crunch.io/api/datasets/1/variables/birthyr/cast/',
-            '{"cast_as":"text"}')
+        expect_POST(
+            type(ds$birthyr) <- "categorical",
+            "https://app.crunch.io/api/datasets/1/variables/birthyr/cast/",
+            '{"cast_as":"categorical"}'
+        )
+        expect_POST(
+            type(ds$birthyr) <- "text",
+            "https://app.crunch.io/api/datasets/1/variables/birthyr/cast/",
+            '{"cast_as":"text"}'
+        )
     })
     test_that("Setting the same type is a no-op", {
         expect_no_request(type(ds$birthyr) <- "numeric")
@@ -23,7 +27,8 @@ with_mock_crunch({
         for (i in c("multiple_response", "categorical_array", "datetime", "foo")) {
             expect_error(type(ds$birthyr) <- i,
                 "is not a Crunch variable type that can be assigned",
-                info=i)
+                info = i
+            )
         }
     })
 
@@ -31,15 +36,16 @@ with_mock_crunch({
         for (i in c("categorical", "text", "numeric", "categorical_array", "datetime", "foo")) {
             expect_error(type(ds$mymrset) <- i,
                 "Cannot change the type of a MultipleResponseVariable by type<-",
-                info=i)
+                info = i
+            )
         }
     })
 })
 
 with_test_authentication({
     test_that("Type changing alters data on the server", {
-        ds <- newDataset(df[,1,drop=FALSE])
-        
+        ds <- newDataset(df[, 1, drop = FALSE])
+
         testvar <- ds$v1
         expect_true(is.Numeric(testvar))
         type(testvar) <- "text"
