@@ -126,11 +126,26 @@ with_mock_crunch({
             '{"digits":0}}}}'
         )
 
-        expect_error(digits(ds$birthyr) <- -1, "digit specifications should be between 0 and 16")
-        expect_error(digits(ds$birthyr) <- 999, "digit specifications should be between 0 and 16")
-        expect_error(digits(ds$birthyr) <- 0.7, "digit specifications should be an integer")
-        expect_error(digits(ds$birthyr) <- "0.7", "digit specifications should be an integer")
-        expect_error(digits(ds$gender) <- 0, "digit specifications can only be set for numeric variables")
+        expect_error(
+            digits(ds$birthyr) <- -1,
+            "digit specifications should be between 0 and 16"
+        )
+        expect_error(
+            digits(ds$birthyr) <- 999,
+            "digit specifications should be between 0 and 16"
+        )
+        expect_error(
+            digits(ds$birthyr) <- 0.7,
+            "digit specifications should be an integer"
+        )
+        expect_error(
+            digits(ds$birthyr) <- "0.7",
+            "digit specifications should be an integer"
+        )
+        expect_error(
+            digits(ds$gender) <- 0,
+            "digit specifications can only be set for numeric variables"
+        )
     })
 })
 
